pub(super) fn should_unload_on_outcome(outcome: InferenceOutcome) -> boolExpand description
Returns true when the worker loop should unload models after inference.
pub(super) fn should_unload_on_outcome(outcome: InferenceOutcome) -> boolReturns true when the worker loop should unload models after inference.